.. R__NAME__ documentation master file, created by
   sphinx-quickstart on Mon Jun 25 20:19:13 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

R__WELCOME__

.. toctree::
   :maxdepth: 2
   :glob:

   tutorial/quickstart
   topics/R__CLEAN_NAME__
   releases/*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
